@@ -4,7 +4,17 @@ use strict;
 use vars qw[ $VERSION ];
 use base qw[ JavaScript::Code::Expression::Op ];
 
-$VERSION = '0.01';
+$VERSION = '0.02';
+
+=head1 NAME
+
+JavaScript::Code::Expression::Op::not
+
+=head1 METHODS
+
+=head2 new
+
+=cut
 
 sub new {
     my $obj   = shift;
@@ -16,9 +26,22 @@ sub new {
     return bless [@_], $class;
 }
 
+=head2 $self->unary
+
+=cut
+
 sub unary      { return 1; }
+
+=head2 $self->precedence( )
+
+=cut
+
 sub precedence { return 300; }
 
+=head2 $self->output( )
+
+=cut
+
 sub output {
     my ( $self, $precedence ) = @_;
     $precedence = 0 if not defined $precedence;
@@ -30,4 +53,20 @@ sub output {
     return $output;
 }
 
+=head1 SEE ALSO
+
+L<JavaScript::Code>
+
+=head1 AUTHOR
+
+Sascha Kiefer, C<esskar@cpan.org>
+
+=head1 LICENSE
+
+This library is free software, you can redistribute it and/or modify it under
+the same terms as Perl itself.
+
+=cut
+
 1;
+
